==> walkers-fabric-1.19.4-5.2-sources.jar: tocraft/walkers/impl/tick/shapes/FrogTickHandler.java <==
//#if MC>1182
package tocraft.walkers.impl.tick.shapes;

import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1657;
import net.minecraft.class_7102;
import tocraft.craftedcore.patched.CEntity;
import tocraft.walkers.api.WalkersTickHandler;

public class FrogTickHandler implements WalkersTickHandler<class_7102> {

    @Override
    public void tick(class_1657 player, class_7102 frog) {
        if (CEntity.level(player).field_9236) {
            boolean walk = CEntity.isOnGround(player) && player.method_18798().method_37268() > 1.0E-6 && !player.method_5816();
            boolean swim = player.method_18798().method_37268() > 1.0E-6 && player.method_5816();

            // Jumping
            if (!CEntity.isOnGround(player) && !swim && !walk && !player.method_5816()) {
                frog.field_37451.method_41324(frog.field_6012);
            } else {
                frog.field_37451.method_41325();
            }

            // Swimming
            if (swim) {
                frog.field_37456.method_41325();
            } else if (player.method_5816()) {
                frog.field_37456.method_41324(frog.field_6012);
            } else {
                frog.field_37456.method_41325();
            }

            // Random croaking
            if (CEntity.level(player).field_9229.method_43058() <= 0.001) {
                frog.field_37452.method_41322(player.field_6012);
            }

            // Tongue
            if (player.field_6252) {
                frog.field_37453.method_41324(player.field_6012);
            } else {
                frog.field_37453.method_41325();
            }
        } else {
            // Buffs - jump boost
            player.method_6092(new class_1293(class_1294.field_5913, 20 * 2, 2, true, false));
        }
    }
}
//#endif

==> walkers-fabric-1.20.1-4.2-sources.jar: tocraft/walkers/impl/tick/shapes/FrogTickHandler.java <==
package tocraft.walkers.impl.tick.shapes;

import net.minecraft.class_1293;
import net.minecraft.class_1294;
import net.minecraft.class_1657;
import net.minecraft.class_7102;
import tocraft.walkers.api.WalkersTickHandler;

public class FrogTickHandler implements WalkersTickHandler<class_7102> {

    @Override
    public void tick(class_1657 player, class_7102 frog) {
        if (player.method_37908().field_9236) {
            boolean walk = player.method_24828() && player.method_18798().method_37268() > 1.0E-6 && !player.method_5816();
            boolean swim = player.method_18798().method_37268() > 1.0E-6 && player.method_5816();

            // Jumping
            if (!player.method_24828() && !swim && !walk && !player.method_5816()) {
                frog.field_37451.method_41324(frog.field_6012);
            } else {
                frog.field_37451.method_41325();
            }

            // Swimming
            if (swim) {
                frog.field_37456.method_41325();
            } else if (player.method_5816()) {
                frog.field_37456.method_41324(frog.field_6012);
            } else {
                frog.field_37456.method_41325();
            }

            // Random croaking
            if (player.method_37908().field_9229.method_43058() <= 0.001) {
                frog.field_37452.method_41322(player.field_6012);
            }

            // Tongue
            if (player.field_6252) {
                frog.field_37453.method_41324(player.field_6012);
            } else {
                frog.field_37453.method_41325();
            }
        } else {
            // Buffs - jump boost
            player.method_6092(new class_1293(class_1294.field_5913, 20 * 2, 2, true, false));
        }
    }
}
